# 交流和反馈

在提出问题之前，请确定你已经大致地将本文档浏览过一遍，这样会节省彼此的一些时间。当然，如果你对文档的组织形式、内容等有任何问题的话，欢迎提出与贡献。

如果你有一些新的想法，可以在 GitHub 上[发起 discussion](https://github.com/yutto-dev/yutto/discussions)，如果你确定你发现了一个 Bug，或者想请求添加新的功能，也可以直接[发起 Issue](https://github.com/yutto-dev/yutto/issues/)。

此外你也可以通过 [Discord](https://discord.com/invite/5cQGyFwsqC) 来与大家讨论，建议问题尽可能直奔主题，尽可能少询问不必要的信息。
